Nox - Flexible test automation for Python
=========================================

|Build Status| |Coverage Status| |PyPI Version| |Docs|

``nox`` is a command-line tool that automates testing in multiple Python
environments, similar to `tox`_. Unlike tox, Nox uses a standard Python
file for configuration.

The latest documentation is available on `Read the Docs`_.

The source code is available on `GitHub`_.


.. |Build Status| image:: https://travis-ci.org/jonparrott/nox.svg
   :target: https://travis-ci.org/jonparrott/nox
.. |Coverage Status| image:: https://codecov.io/github/jonparrott/nox/coverage.svg?branch=master
   :target: https://codecov.io/github/jonparrott/nox?branch=master
.. |PyPI Version| image:: https://img.shields.io/pypi/v/nox-automation.svg
   :target: https://pypi.python.org/pypi/nox-automation
.. |Docs| image:: https://readthedocs.org/projects/nox/badge/?version=latest
   :target: http://nox.readthedocs.org/en/latest/
.. _tox: https://tox.readthedocs.org
.. _Read the Docs: http://nox.readthedocs.org/en/latest/
.. _GitHub: https://github.com/jonparrott/nox
